#
# spec file for package ast-grep
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ast-grep
Version:        0.21.1+0
Release:        1.1
Summary:        A CLI tool for code structural search, lint and rewriting
License:        MIT
URL:            https://ast-grep.github.io/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  gcc-c++

%description
ast-grep(sg) is a CLI tool for code structural search, lint, and rewriting.

%prep
%autosetup -p1 -a1
install -D -m 644 %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

%files
%{_bindir}/%{name}
%license LICENSE
%doc CHANGELOG.md README.md

%changelog
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.1:
  * feat: find defined vars in utils cbc6534
  * fix: add referent rule stack overflow test case f7f24e1
  * feat: add utils defined vars 59001eb
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.21.0:
  * feat: report unused rewriters #1064
  * feat: report undefined error in fix #1070
  * feat: define the resolution order of meta variables #1068
  * feat: export used meta-var in transform #1069
  * feat: export meta variables defined in transform #1066
  * feat: export meta variables defined in constraints/rules #1067
  * test: add test for Pattern::defined_vars method #1065
  * feat: analyze meta variables defined in pattern #1065
  * feat: add field id Error for relational rule #1059
  * feat: support rewrtier check in sub-rule eb4c47c
  * test: add undefined rewriter test d56ad74
  * feat: add used_vars in TemplateFix 641d3b4
* Thu Apr 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.5:
  * fix: add parse global util error 2482a86
  * fix: ignore test 6c2cd46
* Mon Apr  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.4:
  * fix: fix new deprecation note of Rust 2024 a70565e
  * fix: fix quickfix fef3dfc
  * fix: better fix message e0b5875
* Mon Apr  8 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.3:
  * feat(lsp): run "source.fixAll.ast-grep" onsave #1021
  * test: move the integration-test to test folder f2ff77a
  * chore: cargo update 83394e9
  * refactor: move logging and io out of on_apply_all_fix cd79cda
* Thu Mar 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.2:
  * feat: make test --update-all not report error #771
  * fix: fix update cases f8132a4
  * refactor: less indentation for interactive reporter 203bd35
  * feat: improve accept 441a548
* Mon Mar 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.1:
  * feat: respect suppression in lsp #1019
* Mon Mar 25 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.20.0:
  * test: add test for error suppression in scan #1007
  * refactor: merge CombinedScan::scan and CombinedScan::diff #1011
  * feat: report error count instead of file count #1009
  * feat: suppress specific rule #1005
  * fix: skip suppressed error #1006
  * feat: support error/warning suppression #446
  * fix(deps): update babel monorepo da9a938
  * fix(deps): update dependency @swc/core to v1.4.8 d81365a
  * feat: add more states for rule suppression 41a058c
* Mon Mar 11 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.4:
  * LSP default message for diagnostics #970
  * feat: Add error messaging for rule file parsing failures #968
  * feat: add html testing and tweak html #977
  * fix(deps): update dependency @babel/core to v7.24.0 a14741d
  * fix(deps): update dependency @swc/core to v1.4.6 4a397f4
  * fix(deps): update rust crate pyo3 to 0.20.3 23653c2
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.3:
  * fix(deps): update dependency @swc/core to v1.4.2 67450cb
  * refactor: move rewriters to SerializableRuleConfig d98c062
  * fix(deps): update rust crate inquire to 0.7.0 86ec845
* Fri Feb 23 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.2:
  * fix: improve expando char replacement #883
  * feat(napi): add support for napi linux x64 musl c4d7902
  * fix: fix wrong spacing matching 0e8b4f0
  * Update README.md 9636a1a
* Tue Feb 20 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.1:
  * fix: avoid input stream when --update-all #943
  * fix: update cargo lock 8a893e7
  * fix(deps): update dependency @swc/core to v1.4.1 d18fd70
  * chore(deps): update dependency @types/node to v20.11.19 40d3fa0
* Thu Feb 15 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.19.0:
  * Breaking change: refactor: remove unused type generic 9b13d41
  * Breaking change: fix: update pyo3 test ff10e81
  * fix: fix parallel thread output be230ca
* Thu Feb  1 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.1:
  * Breaking change: refactor: use more concise name 6a4a17c
* Wed Jan 31 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.18.0:
  * Breaking change: refactor: remove IndentSensitive trait #868
  * feat: add support for rewriters #855
  * Breaking change: refactor: rename RuleWithConstraints to RuleCore #862
  * feat: move fix to SerializableRuleCore #859
  * Breaking change: refactor: remove MetaVarMatchers beb6f50
  * Breaking change: feat: move fixer to RuleCore 8a43a26
  * Breaking change: refactor: move language out of SerializableRuleCore c5e0dc8
  * Breaking change: refactor: remove Content generic from Fixer 87bbf93
  * Breaking change: feat: improve get_fixer signature e629e0f
  * Breaking change: refactor: make TemplateFix non-generic 0f462a5
  * feat: migrate constraints to Rule 230ee9c
  * refactor: move SerializableRuleCore to rule_core mod 3a303c1
* Sat Jan 13 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.1:
  * feat: respect user's language extension option #848
* Fri Jan 12 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Breaking change: feat: change get_fixer to return Fixer 07c5363
  * feat: add modify_range for tweaking fix range selection eeb2f98
  * feat: rename modify_range -> get_replace_range 54837df
* Sat Jan  6 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * feat: add support for bash and php #639
  * Breaking change: fix: more strict meta var parsing 13ad32b
  * Breaking change: refactor: remove thrift language 26ecdf6
  * fix(deps): update dependency @swc/core to v1.3.102 9ca9711
* Sat Dec 30 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * feat: add language globs to findInFiles in napi #780
  * Breaking change: fix: rename MetaVar for better naming #805
  * refactor: reorgnanize napi file structure 93f8577
  * refactor: move file type related function out of lib 64e33a3
  * feat: handle FileOption in LangOption::infer 7bc3efe
* Mon Dec 18 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * feat: support mutliple rules in -r and --inline-rules #786
  * refactor: unify run_worker and run_std_in #785
  * Breaking change: feat: --stdin now always awaits user input #791
  * feat: support --inline-rules option for sg scan #396
  * refactor: separate PathWorker and StdInWorker and Worker ef3d8ad
  * test: add test cases for sg scan ed35c71
  * fix: revert github action a2f22d8
* Sat Dec 16 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.15.0:
  * Breaking change: feat: reduce metavar_env string allocation e1ab015
  * Breaking change: fix: remove pattern as replacer f6e4293
  * Breaking change: feat: better metavar detection e1ab18a
* Tue Dec 12 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.4:
  * fix: use tempfile to remove vuln #765
  * chore(deps): update dependency typescript to v5.3.3 dbac17d
  * chore(deps): update dependency @napi-rs/cli to v2.17.0 f2d32be
  * chore(deps): update dependency prettier to v3.1.1 990f09b
* Mon Dec 11 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.14.3:
  * feat: add getTransformed in napi #551
  * fix: load custom languages in new command #751
  * chore(deps): update dependency ava to v6 496eb9d
  * feat: add support for Elixir 57edde1
  * feat: rename fixer to TemplateFix 5b53ce0
* Sun Dec 10 2023 Michael Vetter <mvetter@suse.com>
- Initial package of ast-grep 0.14.2 for openSUSE
